@@ -1,8 +1,8 @@
-## ---- echo=FALSE--------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 #file.edit(normalizePath("~/.Renviron"))
 LOCAL <- identical(Sys.getenv("LOCAL"), "TRUE")
 #, eval = LOCAL for skip on CRAN test
-#LOCAL=FALSE
+LOCAL=TRUE#YES
 #knitr::opts_chunk$set(purl = LOCAL, eval=LOCAL)
 knitr::opts_chunk$set(purl = LOCAL)
 NOT_CRAN <- identical(tolower(Sys.getenv("NOT_CRAN")), "TRUE")
@@ -11,5 +11,5 @@ knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
-SAVE_GRAPHS=FALSE
+SAVE_GRAPHS=TRUE#
 
